Font Awesome, the iconic font designed for use with Twitter Bootstrap

# Font Awesome

The iconic font designed for use with Twitter Bootstrap

Download Font
Awesome v2.0 View Project
on GitHub
Watch 3900+ Fork 200+ Follow @fortaweso_me 1000+

### Desktop Font + Vectors

The full desktop font and a pdf of vectors are now included. Happy designing.

### 70 New Icons in v2.0

All requested by our active community on the Font Awesome GitHub project.

### IE7 Support

Font Awesome v2.0 now even supports IE7. If you need it, you have my condolences.

### One font, 220 icons

In a single collection, Font Awesome is a pictographic language of web-related actions.

### Free for commercial use

The Font Awesome webfont and CSS libraries are completely free for commercial use.

### Screen reader compatible

Font Awesome won't trip up screen readers, unlike most icon fonts.

### Made for Twitter Bootstrap

Designed from scratch to be fully backwards compatible with Twitter Bootstrap 2.0.

### CSS control

Easily style icon color, size, shadow, and anything that's possible with CSS.

### Infinite scalability

Scalable vector graphics means icons look awesome at any size.

# New Icons in 2.0

You asked, Font Awesome delivers with 70 shiny new icons in version 2.0. This giant set of new icons was requested on the Font Awesome GitHub project and includes icon parity with Bootstrap 2.0.3.

- icon-beaker
- icon-bell
- icon-bolt
- icon-bookmark-empty
- icon-briefcase
- icon-bullhorn
- icon-caret-down
- icon-caret-left
- icon-caret-right
- icon-caret-up
- icon-certificate
- icon-check-empty
- icon-circle-arrow-down
- icon-circle-arrow-left
- icon-circle-arrow-right
- icon-circle-arrow-up
- icon-cloud
- icon-columns

- icon-comment-alt
- icon-comments-alt
- icon-copy
- icon-credit-card
- icon-cut
- icon-dashboard
- icon-envelope-alt
- icon-facebook
- icon-filter
- icon-fullscreen
- icon-github
- icon-globe
- icon-google-plus-sign
- icon-google-plus
- icon-group
- icon-hand-down
- icon-hand-left
- icon-hand-right

- icon-hand-up
- icon-hdd
- icon-legal
- icon-link
- icon-linkedin
- icon-list-ol
- icon-list-ul
- icon-magic
- icon-money
- icon-paper-clip
- icon-paste
- icon-phone-sign
- icon-phone
- icon-pinterest-sign
- icon-pinterest
- icon-reorder
- icon-rss

- icon-save
- icon-sign-blank
- icon-sitemap
- icon-sort-down
- icon-sort-up
- icon-sort
- icon-strikethrough
- icon-table
- icon-tasks
- icon-truck
- icon-twitter
- icon-umbrella
- icon-underline
- icon-undo
- icon-unlock
- icon-user-md
- icon-wrench

# All Icons by Category

### Web Application Icons

- icon-adjust
- icon-asterisk
- icon-ban-circle
- icon-bar-chart
- icon-barcode
- icon-beaker
- icon-bell
- icon-bolt
- icon-book
- icon-bookmark
- icon-bookmark-empty
- icon-briefcase
- icon-bullhorn
- icon-calendar
- icon-camera
- icon-camera-retro
- icon-certificate
- icon-check
- icon-check-empty
- icon-cloud
- icon-cog
- icon-cogs
- icon-comment
- icon-comment-alt
- icon-comments
- icon-comments-alt
- icon-credit-card
- icon-dashboard
- icon-download
- icon-download-alt
- icon-edit
- icon-envelope
- icon-envelope-alt

- icon-exclamation-sign
- icon-external-link
- icon-eye-close
- icon-eye-open
- icon-facetime-video
- icon-film
- icon-filter
- icon-fire
- icon-flag
- icon-folder-close
- icon-folder-open
- icon-gift
- icon-glass
- icon-globe
- icon-group
- icon-hdd
- icon-headphones
- icon-heart
- icon-heart-empty
- icon-home
- icon-inbox
- icon-info-sign
- icon-key
- icon-leaf
- icon-legal
- icon-lemon
- icon-lock
- icon-unlock
- icon-magic
- icon-magnet
- icon-map-marker
- icon-minus
- icon-minus-sign

- icon-money
- icon-move
- icon-music
- icon-off
- icon-ok
- icon-ok-circle
- icon-ok-sign
- icon-pencil
- icon-picture
- icon-plane
- icon-plus
- icon-plus-sign
- icon-print
- icon-pushpin
- icon-qrcode
- icon-question-sign
- icon-random
- icon-refresh
- icon-remove
- icon-remove-circle
- icon-remove-sign
- icon-reorder
- icon-resize-horizontal
- icon-resize-vertical
- icon-retweet
- icon-road
- icon-rss
- icon-screenshot
- icon-search
- icon-share
- icon-share-alt
- icon-shopping-cart

- icon-signal
- icon-signin
- icon-signout
- icon-sitemap
- icon-sort
- icon-sort-down
- icon-sort-up
- icon-star
- icon-star-empty
- icon-star-half
- icon-tag
- icon-tags
- icon-tasks
- icon-thumbs-down
- icon-thumbs-up
- icon-time
- icon-tint
- icon-trash
- icon-trophy
- icon-truck
- icon-umbrella
- icon-upload
- icon-upload-alt
- icon-user
- icon-user-md
- icon-volume-off
- icon-volume-down
- icon-volume-up
- icon-warning-sign
- icon-wrench
- icon-zoom-in
- icon-zoom-out

### Text Editor Icons

- icon-file
- icon-cut
- icon-copy
- icon-paste
- icon-save
- icon-undo
- icon-repeat
- icon-paper-clip

- icon-text-height
- icon-text-width
- icon-align-left
- icon-align-center
- icon-align-right
- icon-align-justify
- icon-indent-left
- icon-indent-right

- icon-font
- icon-bold
- icon-italic
- icon-strikethrough
- icon-underline
- icon-link
- icon-columns
- icon-table

- icon-th-large
- icon-th
- icon-th-list
- icon-list
- icon-list-ol
- icon-list-ul
- icon-list-alt

### Directional Icons

- icon-arrow-down
- icon-arrow-left
- icon-arrow-right
- icon-arrow-up
- icon-chevron-down

- icon-circle-arrow-down
- icon-circle-arrow-left
- icon-circle-arrow-right
- icon-circle-arrow-up
- icon-chevron-left

- icon-caret-down
- icon-caret-left
- icon-caret-right
- icon-caret-up
- icon-chevron-right

- icon-hand-down
- icon-hand-left
- icon-hand-right
- icon-hand-up
- icon-chevron-up

### Video Player Icons

- icon-play-circle
- icon-play
- icon-pause
- icon-stop

- icon-step-backward
- icon-fast-backward
- icon-backward
- icon-forward

- icon-fast-forward
- icon-step-forward
- icon-eject

- icon-fullscreen
- icon-resize-full
- icon-resize-small

### Social Icons

- icon-phone
- icon-phone-sign
- icon-facebook
- icon-facebook-sign

- icon-twitter
- icon-twitter-sign
- icon-github
- icon-github-sign

- icon-linkedin
- icon-linkedin-sign
- icon-pinterest
- icon-pinterest-sign

- icon-google-plus
- icon-google-plus-sign
- icon-sign-blank

# Examples

Many examples re-used from the Twitter Bootstrap documentation.

Use Font Awesome icons in:

- Bulleted lists (like this one)
- Buttons
- Button groups
- Navigation
- Prepended form inputs
- And many more with Custom CSS

Refresh Checkout Delete

Comment Settings More Info

User

# Integration

It's easy to integrate Font Awesome into Twitter Bootstrap, or even use it on its own.

### Bootstrap using LESS

Use this method if integrating with Twitter Bootstrap using LESS

1. Copy the Font Awesome font directory into your project.
2. Copy font-awesome.less into your bootstrap/less directory.
3. Open bootstrap.less and replace `@import "sprites.less";` with `@import "font-awesome.less";`
4. Open your project's font-awesome.less and edit the font url to ensure it points to the right place.

       @font-face {
         font-family: 'FontAwesome';
         src: url('../font/fontawesome-webfont.eot');
         src: url('../font/fontawesome-webfont.eot?#iefix') format('embedded-opentype'),
            url('../font/fontawesome-webfont.woff') format('woff'),
            url('../font/fontawesome-webfont.ttf') format('truetype'),
            url('../font/fontawesome-webfont.svg#FontAwesome') format('svg');
         font-weight: normal;
         font-style: normal;
       }

5. Re-compile your LESS if using a static compiler. Otherwise, you should be good to go.
6. Check out the examples to start using Font Awesome!

### Bootstrap using CSS

Use this method if integrating with Twitter Bootstrap using CSS.

1. Customize Twitter Bootstrap here. Make sure to uncheck the default "Icons" under "Base CSS."
2. Copy the Font Awesome font directory into your project.
3. Copy font-awesome.css into your project.
4. Open your project's font-awesome.css and edit the font url to ensure it points to the right place (see above example).
5. In the `<head>` of your html, reference the location to your font-awesome.css.

       <link rel="stylesheet" href="../css/bootstrap.css">
       <link rel="stylesheet" href="../css/font-awesome.css">

6. Check out the examples to start using Font Awesome!

### Not using Bootstrap?

Font Awesome works just as well without Twitter Bootstrap.

1. Copy the Font Awesome font directory into your project.
2. Copy font-awesome.less or font-awesome.css into your project.
3. Open your project's font-awesome.less or font-awesome.css and edit the font url to ensure it points to the right place (see above example).
4. Check out the examples to start using Font Awesome!

# Code

### Inline Icon

Place Font Awesome icons just about anywhere with the `<i>` tag.

icon-camera-retro

    <div style="font-size: 24px;">
      <i class="icon-camera-retro"></i> icon-camera-retro
    </div>

Icon classes are echoed via CSS :before.

Increase the icon size by using the `icon-large` class. This increases the size by 33% relative to the font-size of the container.

icon-camera-retro

    <div style="font-size: 24px;">
      <i class="icon-camera-retro icon-large"></i> icon-camera-retro
    </div>

### Buttons

Refresh Checkout

Comment Delete

Settings More Info

Font Awesome icons work great in buttons.

    <a class="btn" href="#">
      <i class="icon-refresh"></i> Refresh</a>
    <a class="btn btn-success" href="#">
      <i class="icon-shopping-cart icon-large"></i> Checkout</a>
    <a class="btn btn-large btn-primary" href="#">
      <i class="icon-comment"></i> Comment</a>
    <a class="btn btn-danger" href="#">
      <i class="icon-trash icon-large"></i> Delete</a>
    <a class="btn btn-small" href="#">
      <i class="icon-cog"></i> Settings</a>
    <a class="btn btn-small btn-info" href="#">
      <i class="icon-info-sign"></i> More Info</a>

### Button groups

    <div class="btn-group">
      <a class="btn" href="#"><i class="icon-align-left"></i></a>
      <a class="btn" href="#"><i class="icon-align-center"></i></a>
      <a class="btn" href="#"><i class="icon-align-right"></i></a>
      <a class="btn" href="#"><i class="icon-align-justify"></i></a>
    </div>

### Button dropdowns

User

    <div class="btn-group">
        <a class="btn btn-primary" href="#"><i class="icon-user"></i> User</a>
        <a class="btn btn-primary dropdown-toggle" data-toggle="dropdown" href="#"><span class="icon-caret-down"></span></a>
        <ul class="dropdown-menu">
            <li><a href="#"><i class="icon-pencil"></i> Edit</a></li>
            <li><a href="#"><i class="icon-trash"></i> Delete</a></li>
            <li><a href="#"><i class="icon-ban-circle"></i> Ban</a></li>
            <li class="divider"></li>
            <li><a href="#"><i class="i"></i> Make admin</a></li>
        </ul>
    </div>

Don't forget to add the appropriate JavaScript to enable button dropdowns.

### Lists

- Lists
- Buttons
- Button groups
- Navigation
- Prepended form inputs

Easily replace individual bullets.

    <ul class="icons">
      <li><i class="icon-ok"></i> Lists</li>
      <li><i class="icon-ok"></i> Buttons</li>
      <li><i class="icon-ok"></i> Button groups</li>
      <li><i class="icon-ok"></i> Navigation</li>
      <li><i class="icon-ok"></i> Prepended form inputs</li>
    </ul>

### Navigation

Use Font Awesome icons in navigation to provide helpful visual cues.

    <ul class="nav nav-list">
      <li class="active"><a href="#"><i class="icon-home"></i> Home</a></li>
      <li><a href="#"><i class="icon-book"></i> Library</a></li>
      <li><a href="#"><i class="icon-pencil"></i> Applications</a></li>
      <li><a href="#"><i class="icon-cogs"></i> Settings</a></li>
    </ul>

### Prepended form inputs

    <form>
      <div class="input-prepend">
        <span class="add-on"><i class="icon-envelope"></i></span>
        <input class="span2" type="text" placeholder="Email address">
      </div>
      <div class="input-prepend">
        <span class="add-on"><i class="icon-key"></i></span>
        <input class="span2" type="password" placeholder="Password">
      </div>
    </form>

### Custom CSS

Anything you can do with CSS font effects, you can do with Font Awesome.

Star Ratings (inspired by CSS Tricks)

# Roadmap

Here's the plan for future updates.

- Font sub-setting. Keep your font file sizes small by only using the icons you need.
- Better hinting for smaller font sizes.
- More icons. Have any requests? Open an issue in the Font Awesome GitHub project.
- More complete Twitter Bootstrap compatibility.
- Tricks and tips for super-awesome creative CSS methods, like the star example above.